summaryrefslogtreecommitdiff
path: root/lib/sqlalchemy/engine
diff options
context:
space:
mode:
authorDiana Clarke <diana.joan.clarke@gmail.com>2012-12-06 00:00:17 -0500
committerDiana Clarke <diana.joan.clarke@gmail.com>2012-12-06 00:00:17 -0500
commit54f45deb9744863da7dbb276e5204d37a7993927 (patch)
treef0af30e22eb0e078b030d542e89ea6fb340fd9e8 /lib/sqlalchemy/engine
parent73f25332b96988c34c17e39ffbd4f96e0c4c1967 (diff)
downloadsqlalchemy-54f45deb9744863da7dbb276e5204d37a7993927.tar.gz
fixing broken links (see #2625)
Diffstat (limited to 'lib/sqlalchemy/engine')
-rw-r--r--lib/sqlalchemy/engine/base.py14
-rw-r--r--lib/sqlalchemy/engine/result.py10
2 files changed, 12 insertions, 12 deletions
diff --git a/lib/sqlalchemy/engine/result.py b/lib/sqlalchemy/engine/result.py
index 98b0ea4b2..dcfd5ac31 100644
--- a/lib/sqlalchemy/engine/result.py
+++ b/lib/sqlalchemy/engine/result.py
@@ -557,7 +557,7 @@ class ResultProxy(object):
supports "returning" and the insert statement executed
with the "implicit returning" enabled.
- Raises :class:`.InvalidRequestError` if the executed
+ Raises :class:`~sqlalchemy.exc.InvalidRequestError` if the executed
statement is not a compiled expression construct
or is not an insert() construct.
@@ -583,7 +583,7 @@ class ResultProxy(object):
"""Return the collection of updated parameters from this
execution.
- Raises :class:`.InvalidRequestError` if the executed
+ Raises :class:`~sqlalchemy.exc.InvalidRequestError` if the executed
statement is not a compiled expression construct
or is not an update() construct.
@@ -605,7 +605,7 @@ class ResultProxy(object):
"""Return the collection of inserted parameters from this
execution.
- Raises :class:`.InvalidRequestError` if the executed
+ Raises :class:`~sqlalchemy.exc.InvalidRequestError` if the executed
statement is not a compiled expression construct
or is not an insert() construct.
@@ -639,7 +639,7 @@ class ResultProxy(object):
See :class:`.ExecutionContext` for details.
- Raises :class:`.InvalidRequestError` if the executed
+ Raises :class:`~sqlalchemy.exc.InvalidRequestError` if the executed
statement is not a compiled expression construct
or is not an insert() or update() construct.
@@ -661,7 +661,7 @@ class ResultProxy(object):
See :class:`.ExecutionContext` for details.
- Raises :class:`.InvalidRequestError` if the executed
+ Raises :class:`~sqlalchemy.exc.InvalidRequestError` if the executed
statement is not a compiled expression construct
or is not an insert() or update() construct.
diff --git a/lib/sqlalchemy/engine/base.py b/lib/sqlalchemy/engine/base.py
index fdeeac516..e3b09e63a 100644
--- a/lib/sqlalchemy/engine/base.py
+++ b/lib/sqlalchemy/engine/base.py
@@ -121,7 +121,7 @@ class Connection(Connectable):
Note that any key/value can be passed to
:meth:`.Connection.execution_options`, and it will be stored in the
- ``_execution_options`` dictionary of the :class:`.Connnection`. It
+ ``_execution_options`` dictionary of the :class:`.Connection`. It
is suitable for usage by end-user schemes to communicate with
event listeners, for example.
@@ -1295,8 +1295,8 @@ class TwoPhaseTransaction(Transaction):
class Engine(Connectable, log.Identified):
"""
Connects a :class:`~sqlalchemy.pool.Pool` and
- :class:`~sqlalchemy.engine.Dialect` together to provide a source
- of database connectivity and behavior.
+ :class:`~sqlalchemy.engine.interfaces.Dialect` together to provide a
+ source of database connectivity and behavior.
An :class:`.Engine` object is instantiated publicly using the
:func:`~sqlalchemy.create_engine` function.
@@ -1426,15 +1426,15 @@ class Engine(Connectable, log.Identified):
@property
def name(self):
- """String name of the :class:`~sqlalchemy.engine.Dialect` in use by
- this ``Engine``."""
+ """String name of the :class:`~sqlalchemy.engine.interfaces.Dialect`
+ in use by this :class:`Engine`."""
return self.dialect.name
@property
def driver(self):
- """Driver name of the :class:`~sqlalchemy.engine.Dialect` in use by
- this ``Engine``."""
+ """Driver name of the :class:`~sqlalchemy.engine.interfaces.Dialect`
+ in use by this :class:`Engine`."""
return self.dialect.driver